OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Додато у омиљено",
    "Removed from favorites" : "Избачено из омиљених",
    "You added {file} to your favorites" : "Додали сте {file} у омиљене",
    "You removed {file} from your favorites" : "Избацили сте {file} из омиљених",
    "Favorites" : "Омиљени",
    "File changes" : "Измене над фајлом",
    "Created by {user}" : "Направио {user}",
    "Changed by {user}" : "Изменио {user}",
    "Deleted by {user}" : "Обрисао {user}",
    "Restored by {user}" : "Повратио {user}",
    "Renamed by {user}" : "Преименовао {user}",
    "Moved by {user}" : "Померио {user}",
    "\"remote account\"" : "„удаљени налог”",
    "You created {file}" : "Направили сте {file}",
    "You created an encrypted file in {file}" : "Направили сте шифровани фајл {file}",
    "{user} created {file}" : "{user} је направио {file}",
    "{user} created an encrypted file in {file}" : "{user} је направио шифровани фајл {file}",
    "{file} was created in a public folder" : "{file} је направљен у јавној фасцикли",
    "You changed {file}" : "Изменили сте {file}",
    "You changed an encrypted file in {file}" : "Изменили сте шифровани фајл {file}",
    "{user} changed {file}" : "{user} је изменио {file}",
    "{user} changed an encrypted file in {file}" : "{user} је изменио шифровани фајл {file}",
    "You deleted {file}" : "Обрисали сте {file}",
    "You deleted an encrypted file in {file}" : "Обрисали сте шифровани фајл {file}",
    "{user} deleted {file}" : "{user} је обрисао {file}",
    "{user} deleted an encrypted file in {file}" : "{user} је обрисао шифровани фајл {file}",
    "You restored {file}" : "Повратили сте {file}",
    "{user} restored {file}" : "{user} је повратио {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Променили сте име фајла {oldfile} (скривено) на {newfile} (скривено)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Променили сте име фајла {oldfile} (скривено) на {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Променили сте име фајла {oldfile} на {newfile} (скривено)",
    "You renamed {oldfile} to {newfile}" : "Преименовали сте {oldfile} на {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} је променио име фајла {oldfile} (скривено) на {newfile} (скривено)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} је променио име фајла {oldfile} (скривено) на {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} је променио име фајла {oldfile} на {newfile} (скривено)",
    "{user} renamed {oldfile} to {newfile}" : "{user} је преименовао {oldfile} на {newfile}",
    "You moved {oldfile} to {newfile}" : "Померили сте {oldfile} на {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} је померио {oldfile} на {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Фајл је додат или избрисан из Ваших <strong>омиљених</strong>",
    "Files" : "Фајлови",
    "A file or folder has been <strong>changed</strong>" : "Фајл или фасцикла су <strong>измењени</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Омиљени фајл или фасцикла су <strong>измењени</strong>",
    "Failed to authorize" : "Није успело добијање дозволе",
    "Invalid folder path" : "Неисправна путања фолдера",
    "Folder not found" : "Није пронађен фолдер",
    "Upload (max. %s)" : "Отпремање (макс. %s)",
    "Accept" : "Прихвати",
    "Reject" : "Одбаци",
    "Incoming ownership transfer from {user}" : "Надолазећи пренос власништва од корисника {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Да ли желите да прихватите {path}?\n\nПажња: После прихватања, процес трансфера може потрајати и до 1h.",
    "Ownership transfer denied" : "Пренос власништва је одбијен",
    "Your ownership transfer of {path} was denied by {user}." : "Корисник {user} је одбио ваш пренос власништва над {path}.",
    "Ownership transfer failed" : "Пренос власништва није успео",
    "Your ownership transfer of {path} to {user} failed." : "Ваш пренос власништва {path} на корисника {user} није успео.",
    "The ownership transfer of {path} from {user} failed." : "Пренос власништва {path} на корисника {user} није успео.",
    "Ownership transfer done" : "Пренос власништва завршен",
    "Your ownership transfer of {path} to {user} has completed." : "Ваш пренос власништва {path} на корисника {user} завршен.",
    "The ownership transfer of {path} from {user} has completed." : "Пренос власништва {path} на корисника {user} завршен.",
    "in %s" : "за %s",
    "Transferred from %1$s on %2$s" : "Пренесено са %1$s на %2$s",
    "Files compatibility" : "Компатибилност фајлова",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Дозвољава се ограничавање имена фајлова тако да сви клијенти могу да их синхронизују. Подразумевано се дозвољавају сва имена фајлова која су исправна на POSIX системима (нпр. Linux или macOS).",
    "Enforce Windows compatibility" : "Форсирај Windows компатибилност",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Ово ће да блокира имена фајлова која су неисправна на Windows системима, као што су она која користе резервисана имена или специјалне карактере. Али ово неће форсирати компатибилност разликовања малих и великих слова.",
    "File Management" : "Управљање фајловима",
    "Current directory path" : "Путања текућег директоријума",
    "Home" : "Почетна",
    "Target folder does not exist any more" : "Одредишна фасцикла више не постоји",
    "Reload current directory" : "Поново учитај текући директоријум",
    "Go to the \"{dir}\" directory" : "Иди у „{dir}” дирекотријум",
    "Drag and drop files here to upload" : "Да отпремите, превуците и отпустите фајлове овде",
    "Your have used your space quota and cannot upload files anymore" : "Искористили сте квоту простора и више не можете да отпремате фајлове",
    "You don’t have permission to upload or create files here" : "Немате дозволе да овде отпремате или стварате фајлове",
    "Favorite" : "Омиљено",
    "\"{displayName}\" action executed successfully" : "Акција „{displayName}” је успешно извршена",
    "\"{displayName}\" action failed" : "Акција „{displayName}” није успела",
    "Toggle selection for file \"{displayName}\"" : "Укљ./искљ. избор за фајл „{displayName}”",
    "Toggle selection for folder \"{displayName}\"" : "Укљ./искљ. избор за фолдер „{displayName}”",
    "File is loading" : "Фајл се учитава",
    "Folder is loading" : "Фолдер се учитава",
    "Rename file" : "Промени назив фајла",
    "Filename" : "Назив фајла",
    "Folder name" : "Назив фасцикле",
    "This node is unavailable" : "Овај чвор није доступан",
    "Another entry with the same name already exists." : "Већ постоји ставка са истим именом.",
    "Invalid filename." : "Неисправно име фајла.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "„{oldName}” је промењено на „{newName}”",
    "Pending" : "На чекању",
    "Clear filter" : "Очисти филтер",
    "Modified" : "Измењен",
    "Type" : "Тип",
    "Active filters" : "Активни филтери",
    "Remove filter" : "Уклони филтер",
    "Total rows summary" : "Резиме укупног броја редова",
    "Name" : "Назив",
    "Size" : "Величина",
    "Toggle selection for all files and folders" : "Укљ./искљ. избор за све фајлове и фолдере",
    "Actions" : "Радње",
    "(selected)" : "(изабрано)",
    "\"{displayName}\" failed on some elements " : "„{displayName}” није успело на неким елементима",
    "\"{displayName}\" batch action executed successfully" : "Пакетна акција „{displayName}” се успешно извршила",
    "{count} selected" : "{count} изабрано",
    "List of files and folders." : "Листа фајлова и фолдера.",
    "Column headers with buttons are sortable." : "Заглавља колона са дугмићима могу да се соритрају.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Ова листа није у потпуности приказана из разлога перформанси. Фајлови ће се приказивати како се крећете кроз листу.",
    "File not found" : "Фајл није нађен",
    "Storage information" : "Информације о складишту",
    "Storage quota" : "Квота складишта",
    "{usedQuotaByte} used" : "{usedQuotaByte} искоришћено",
    "{used} of {quota} used" : "{used} од {quota} искоришћено",
    "{relative}% used" : "{relative}% искоришћено",
    "Could not refresh storage stats" : "Статистике складишта нису могле да се освеже",
    "Your storage is full, files can not be updated or synced anymore!" : "Ваше складиште је пуно. Фајлови више не могу бити ажурирани ни синхронизовани!",
    "Create" : "Направи",
    "New folder" : "Нова фасцикла",
    "Create new folder" : "Направи нову фасциклу",
    "This name is already in use." : "Ово име се већ користи.",
    "Fill template fields" : "Попуните поља шаблона",
    "Submitting fields…" : "Поља се подносе…",
    "Submit" : "Пошаљи",
    "Transfer ownership of a file or folder" : "Пренеси власништво фајла или фасцикле",
    "Choose file or folder to transfer" : "Одаберите фајл или фасциклу за пренос",
    "Change" : "Измени",
    "New owner" : "Нови власник",
    "Choose a file or folder to transfer" : "Одаберите фајл или фасциклу за пренос",
    "Transfer" : "Пренеси",
    "Transfer {path} to {userid}" : "Пренеси {path} на корисника {userid}",
    "Invalid path selected" : "Одабрана неисправна путања",
    "Unknown error" : "Непозната грешка",
    "Ownership transfer request sent" : "Послат захтев за пренос власништва",
    "Cannot transfer ownership of a file or folder you do not own" : "Не можете да пренесете власништво над фајлом или фолдером који не поседујете",
    "Select file or folder to link to" : "Изаберите фајл или фолдер на који показује линк",
    "Choose {file}" : "Изабери {file}",
    "New" : "Нов",
    "Loading current folder" : "Учитавање текућег фолдера",
    "Retry" : "Покушај поново",
    "No files in here" : "Овде нема фајлова",
    "Upload some content or sync with your devices!" : "Отпремите неки садржај или синхронизујте са вашим уређајима!",
    "Go back" : "Иди назад",
    "Share" : "Пдели",
    "Shared by link" : "Дељени путем везе",
    "Shared" : "Подељено",
    "Switch to list view" : "Пређи на поглед листе",
    "Switch to grid view" : "Пређи на поглед мреже",
    "Upload was cancelled by user" : "Корисник је прекинуо отпремање",
    "Not enough free space" : "Нема довољно слободног места",
    "Operation is blocked by access control" : "Контрола приступа је блокирала операцију",
    "Error during upload: {message}" : "Грешка при отпремању: {message}",
    "Error during upload, status code {status}" : "Грешка приликом отпремања, кôд статуса {status}",
    "Unknown error during upload" : "Непозната грешка током отпремања",
    "Filter filenames…" : "Филтрирање имена фајлова…",
    "Views" : "Прикази",
    "Files settings" : "Подешавања фајлова",
    "File cannot be accessed" : "Фајлу не може да се приступи",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Фајл није могао да се пронађе или немате дозволу да га прегледате. Замолите пошиљаоца да га подели.",
    "Your files" : "Ваши фајлови",
    "Open in files" : "Отвори у фајловима",
    "Sort favorites first" : "Сортирај прво омиљене",
    "Sort folders before files" : "Поређај фолдере испред фајлова",
    "Show hidden files" : "Прикажи скривене фајлове",
    "Crop image previews" : "Опсецање прегледа слика",
    "Enable the grid view" : "Укључи приказ мреже",
    "Enable folder tree" : "Укључи стабло фолдера",
    "Additional settings" : "Додатне поставке",
    "WebDAV" : "ВебДАВ",
    "WebDAV URL" : "WebDAV URL",
    "Copy to clipboard" : "Копирај у оставу",
    "Use this address to access your Files via WebDAV" : "Користи ову адресу да приступате Вашим фајловима преко ВебДАВа",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Ако сте укључили 2FA, морате кликом овде да крерате нову лозинку апликације.",
    "Clipboard is not available" : "Клипборд није доступан",
    "WebDAV URL copied to clipboard" : "WebDAV URL је копиран у клипборд",
    "Owner" : "Власник",
    "Remove from favorites" : "Избаци из омиљених",
    "Add to favorites" : "Додај у омиљене",
    "Tags" : "Ознаке",
    "You" : "Ви",
    "Shared multiple times with different people" : "Дељено више пута са разним људима",
    "Unable to change the favourite state of the file" : "Неуспела промена стања омиљености фајла",
    "Error while loading the file data" : "Грешка при учитавању података фајла",
    "Pick a template for {name}" : "Изаберите шаблон за {name}",
    "Create a new file with the selected template" : "Креирање новог фајла по изабраном шаблону",
    "Creating file" : "Креирање фајла",
    "Blank" : "Празно",
    "Unable to create new file from template" : "Из шаблона није могао да се креира нови фајл",
    "Deletion cancelled" : "Брисање је отказано",
    "Delete permanently" : "Обриши заувек",
    "Delete and unshare" : "Обриши и прекини дељење",
    "Leave this share" : "Напусти ово дељење",
    "Leave these shares" : "Напусти ова дељења",
    "Disconnect storage" : "Искључи складиште",
    "Disconnect storages" : "Искључи складишта",
    "Delete file" : "Обриши фајл",
    "Delete files" : "Обриши фајлове",
    "Delete folder" : "Обрши фолдер",
    "Delete folders" : "Обриши фолдере",
    "Delete" : "Обриши",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Управо ћете неповратно обрисати {count} ставку","Управо ћете неповратно обрисати {count} ставке","Управо ћете неповратно обрисати {count} ставки"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Управо ћете обрисати {count} ставку","Управо ћете обрисати {count} ставке","Управо ћете обрисати {count} ставки"],
    "Confirm deletion" : "Потврди брисање",
    "Cancel" : "Поништи",
    "Edit file locally" : "Уреди фајл локално",
    "The file should now open locally. If you don't see this happening, make sure that the desktop client is installed on your system." : "Фајл би сата требало да се отвори локално. Ако се то не деси, обезбедите да је десктоп клијент инсталиран на вашем систему.",
    "Retry local edit" : "Пробај поново локално уређивање",
    "Edit online" : "Уреди на мрежи",
    "Failed to redirect to client" : "Преусмеравање на клијента није успело",
    "Edit locally" : "Уреди локално",
    "Moving \"{source}\" to \"{destination}\" …" : "„{source}” се премешта у „{destination}”…",
    "Copying \"{source}\" to \"{destination}\" …" : "„{source}” се копира у „{destination}”…",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Фајл/фолдер не можете да преместите у самог себе или у његов подфолдер",
    "(copy)" : "(копиран)",
    "(copy %n)" : "(копирано %n)",
    "Move cancelled" : "Премештање је отказано",
    "A file or folder with that name already exists in this folder" : "У овом фолдеру већ постоји фајл или фолдер са тим именом",
    "The files are locked" : "Фајлови су закључани",
    "The file does not exist anymore" : "Фајл више не постоји",
    "Choose destination" : "Изаберите одредиште",
    "Copy to {target}" : "Копирај у {target}",
    "Copy" : "Копирај",
    "Move to {target}" : "Премести у {target}",
    "Move" : "Помери",
    "Move or copy operation failed" : "Није успела операција премештања или копирања",
    "Move or copy" : "Помери или копирај",
    "Cancelled move or copy of \"{filename}\"." : "Операција премештања или копирања „{filename}” је отказана.",
    "Cancelled move or copy operation" : "Операција премештања или копирања је отказана",
    "Open folder {displayName}" : "Отвори фолдер {displayName}",
    "Open in Files" : "Отвори у Фајловима",
    "Rename" : "Преименуј",
    "Open details" : "Отвори детаље",
    "View in folder" : "Види у фасцикли",
    "Today" : "Данас",
    "Last 7 days" : "Последњих 7 дана",
    "Last 30 days" : "Последњих 30 дана",
    "This year ({year})" : "Ове године ({year})",
    "Last year ({year})" : "Прошле године ({year})",
    "Documents" : "Документи",
    "Spreadsheets" : "Табеле",
    "Presentations" : "Презентације",
    "PDFs" : "PDF фајлови",
    "Folders" : "Фолдери",
    "Audio" : "Звук",
    "Photos and images" : "Фотографије и слике",
    "Videos" : "Видео снимци",
    "New folder creation cancelled" : "Отказане је креирање новог фолдера",
    "Created new folder \"{name}\"" : "Креиран је нови фолдер „{name}”",
    "Unable to initialize the templates directory" : "Фолдер са шаблонима није могао да се иницијализује",
    "Create templates folder" : "Креирај фолдер шаблона",
    "Templates" : "Шаблони",
    "New template folder" : "Нови фолдер шаблона",
    "In folder" : "У фолдеру",
    "Search in folder: {folder}" : "Претрага у фолдеру: {folder}",
    "One of the dropped files could not be processed" : "Један од упуштених фајлова не може да се обради",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Ваш интернет прегледач не подржава Filesystem API. Нећете моћи да отпремате директоријуме",
    "No files to upload" : "Нема фајлова за отпремање",
    "Unable to create the directory {directory}" : "Не може да се креира директоријум {directory}",
    "Some files could not be uploaded" : "Неки фајлови нису могли да се отпреме",
    "Files uploaded successfully" : "Фајлови су успешно отремљени",
    "No files to process" : "Нема фајлова за обраду",
    "Some files could not be copied" : "Неки фајлови нису могли да се копирају",
    "Some files could not be moved" : "Неке фајлове нисам могао да преместим",
    "Files copied successfully" : "Фајлови су успешно копирани",
    "Files moved successfully" : "Фајлови су успешно премештени",
    "Conflicts resolution skipped" : "Прексочено је разрешавање конфилката",
    "Upload cancelled" : "Отпремање је отказано",
    "This operation is forbidden" : "Ова радња је забрањена",
    "This directory is unavailable, please check the logs or contact the administrator" : "Овај директоријум није доступан, проверите дневник или контактирајте администратора",
    "Storage is temporarily not available" : "Складиште привремено није  доступно",
    "Unexpected error: {error}" : "Неочекивана грешка: {error}",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} фолдер","{folderCount} фолдера","{folderCount} фолдера"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} фајл","{fileCount} фајла","{fileCount} фајлова"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 фајл и {folderCount} фолдер","1 фајл и {folderCount} фолдера","1 фајл и {folderCount} фолдера"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} фајл и 1 фолдер","{fileCount} фајла и 1 фолдер","{fileCount} фајлова и 1 фолдер"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} фајлова и {folderCount} фолдера",
    "Filename must not be empty." : "Назив фајла не може бити празан.",
    "\"{char}\" is not allowed inside a filename." : "„{char}“ није дозвољен карактер у имену фајла.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "„{segment}” је резервисано име и не сме се користити као име фајла.",
    "\"{extension}\" is not an allowed filetype." : "„{extension}” није дозвољени тип фајла.",
    "Filenames must not end with \"{extension}\"." : "Имена фајлова не смеју да се завршавају са „{extension}”.",
    "List of favorite files and folders." : "Листа омиљених фајлова и фолдера.",
    "No favorites yet" : "Још нема омиљених",
    "Files and folders you mark as favorite will show up here" : "Фајлови и фасцикле које обележите као омиљене појавиће се овде",
    "All files" : "Сви фајлови",
    "List of your files and folders." : "Листа ваших фајлова и фолдера.",
    "All folders" : "Сви фолдери",
    "Personal Files" : "Лични фајлови",
    "List of your files and folders that are not shared." : "Листа ваших фајлова и фолдера који се не деле.",
    "No personal files found" : "Није пронађен ниједан лични фајл",
    "Files that are not shared will show up here." : "Овде ће се појавити фајлови који се не деле.",
    "Recent" : "Скорашњи",
    "List of recently modified files and folders." : "Листа фајлова и директоријума који су недавно измењени.",
    "No recently modified files" : "Нема недавно промењених фајлова",
    "Files and folders you recently modified will show up here." : "Овде ће се појавити фајлови и фолдери које сте недавно изменили.",
    "You do not have permission to upload or create files here" : "Немате дозволу да овде отпреминте или креирате фајлове",
    "No entries found in this folder" : "Нема ничега у овој фасцикли",
    "Select all" : "Означи све",
    "Upload too large" : "Отпремање је превелико",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Фајлови које желите да отпремите превазилазе ограничење отпремања на овом серверу.",
    "File could not be found" : "Фајл није нађен",
    "Download" : "Преузми",
    "Show list view" : "Prikaži prikaz liste",
    "Show grid view" : "Prikaži prikaz mreže",
    "Close" : "Затвори",
    "Could not create folder \"{dir}\"" : "Не могу да направим фасциклу „{dir}“",
    "This will stop your current uploads." : "Ово ће да прекине тренутна отпремања.",
    "Upload cancelled." : "Отпремање је отказано.",
    "Processing files …" : "Обрађујем фајлове…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Не могу да отпремим {filename} јер је то или директоријум или има 0 бајтова",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Нема простора. Отпремате {size1} али само {size2} је преостало",
    "Target folder \"{dir}\" does not exist any more" : "Одредишна фасцикла „{dir}“ више не постоји",
    "An unknown error has occurred" : "Десила се непозната грешка",
    "File could not be uploaded" : "Фајл не може да се отпреми",
    "Uploading …" : "Отпремам…",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Отпремање … ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} од {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Отпремање те ставке није подржано",
    "Error when assembling chunks, status code {status}" : "Грешки при прикупљању делова фајла, статус код {status}",
    "Choose target folder" : "Одаберите одредишну фасциклу",
    "Set reminder" : "Постави подсетник",
    "Open" : "Отвори",
    "Could not load info for file \"{file}\"" : "Не могу да учитам информације фајла „{file}“",
    "Details" : "Детаљи",
    "Please select tag(s) to add to the selection" : "Молимо вас да изаберете ознаку (или више њих) која треба да се дода избору",
    "Apply tag(s) to selection" : "Примени ознаку (или више њих) на избор",
    "Select directory \"{dirName}\"" : "Избор директоријума „{dirName}",
    "Select file \"{fileName}\"" : "Избор фајла „{fileName}”",
    "Unable to determine date" : "Не могу да одредим датум",
    "Could not move \"{file}\", target exists" : "Не могу да преместим „{file}“. Одредиште већ постоји",
    "Could not move \"{file}\"" : "Не могу да преместим „{file}“",
    "copy" : "копиран",
    "Could not copy \"{file}\", target exists" : "Не могу да копирам „{file}“, одредиште већ постоји",
    "Could not copy \"{file}\"" : "Не могу да копирам „{file}“",
    "Copied {origin} inside {destination}" : "Копиран {origin} у {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Копиран{origin} и још {nbfiles} других фајлова у {destination}",
    "{newName} already exists" : "{newName} већ постоји",
    "Could not rename \"{fileName}\", it does not exist any more" : "Не могу да преименујем „{fileName}“. Фајл више не постоји",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Назив „{targetName}“ се већ користи у фасцикли „{dir}“. Одаберите неко друго име.",
    "Could not rename \"{fileName}\"" : "Не могу да преименујем „{fileName}“",
    "Could not create file \"{file}\"" : "Не могу да направим фајл „{file}“",
    "Could not create file \"{file}\" because it already exists" : "Не могу да направим фајл „{file}“ јер већ постоји",
    "Could not create folder \"{dir}\" because it already exists" : "Не могу да направим фасциклу „{dir}“ јер већ постоји",
    "Could not fetch file details \"{file}\"" : "Не могу да дохватим детаље за „{file}“",
    "Error deleting file \"{fileName}\"." : "Грешка при брисању фајла „{fileName}“.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Нема резултата претраге у осталим фасциклама за {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Унесите више од два карактера да претражујете у другим фасциклама",
    "_%n folder_::_%n folders_" : ["%n фасцикла","%n фасцикле","%n фасцикли"],
    "_%n file_::_%n files_" : ["%n фајл","%n фајла","%n фајлова"],
    "{dirs} and {files}" : "{dirs} и {files}",
    "_including %n hidden_::_including %n hidden_" : ["укључујући и %n скривени","укључујући и %n скривена","укључујући и %n скривених"],
    "_Uploading %n file_::_Uploading %n files_" : ["Отпремам %n фајл","Отпремам %n фајла","Отпремам %n фајлова"],
    "New file/folder menu" : "Мени за нови фајл/фолдер",
    "Select file range" : "Одаберите опсег фајлова",
    "{used}%" : "{used}%",
    "{used} used" : "{used} искоришћено",
    "\"{name}\" is an invalid file name." : "„{name}“ није исправан назив фајла.",
    "File name cannot be empty." : "Назив фајла не може бити празан.",
    "\"/\" is not allowed inside a file name." : "„/“ није дозвољен каракетер у имену фајла.",
    "\"{name}\" is not an allowed filetype" : "„{name}“ није дозвољени тип фајла",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Складиште власника {owner} је пуно, више није могуће отпремање или синхронизација фајлова!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Групни фолдер „{mountPoint}” је пун, фајлови више не могу да се ажурирају или синхронизују!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Спаљно складиште „{mountPoint}” је пуно, фајлови више не могу да се ажурирају или синхронизују!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Ваше складиште је пуно, фајлови випе не могу да се ажурирају или синхронизују!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Складиште корисника {owner} је скоро пуно ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Групна фасцикла „{mountPoint}“ је скоро пуна ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Спољашње складиште „{mountPoint}“ је скоро пуно ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Ваше складиште је скоро пуно ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["се подудара са „{filter}”","се подударају са „{filter}","се подудара са „{filter}"],
    "Direct link was copied (only works for users who have access to this file/folder)" : "Копиран је директан линк (функционише само за кориснике који имају приступ овом фајлу/фолдеру)",
    "Path" : "Путања",
    "_%n byte_::_%n bytes_" : ["%n бајт","%n бајта","%n бајтова"],
    "Favorited" : "Омиљено",
    "Copy direct link (only works for users who have access to this file/folder)" : "Копирај директну везу (ради само за кориснике који имају приступ овом фајлу/фасциклу)",
    "Upload file" : "Отпреми фајл",
    "Not favorited" : "Није омиљено",
    "An error occurred while trying to update the tags" : "Дошло је до грешке при покушају ажурирања ознака",
    "\"remote user\"" : "„удаљени корисник“",
    "{newName} already exists." : "{newName} већ постоји.",
    "\"{segment}\" is not allowed inside a filename." : "„{segment}” није дозвољено у имену фајла.",
    "\"{segment}\" is a forbidden file or folder name." : "„{segment}” је забрањено име фајла или фолдера.",
    "\"{segment}\" is not an allowed filetype." : "„{segment}” није дозвољени тип фајла.",
    "Filenames must not end with \"{segment}\"." : "Имена фајлова не смеју да се завршавају са „{segment}”.",
    "Name cannot be empty" : "Назив не може бити празан",
    "Another entry with the same name already exists" : "Већ постоји ставка са истим именом.",
    "Could not rename \"{oldName}\", it does not exist any more" : "Не може да се промени име фајла „{fileName}” јер фајл више не постоји",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Назив „{targetName}” се већ користи у директоријуму „{dir}”. Молимо вас да изаберете неко друго име.",
    "Could not rename \"{oldName}\"" : "Не може да се промени име фајла „{fileName}”",
    "Storage informations" : "Информације о складишту",
    "Choose file" : "Изаберите фајл",
    "Go to the previous folder" : "Иди на претходни фолдер",
    "Open the files app settings" : "Отвори подешавања апликације фајлови",
    "You might not have have permissions to view it, ask the sender to share it" : "Можда немате дозволе да га погледате, затражите од пошиљаоца да га подели са вама",
    "The files is locked" : "Фајл је закључан",
    "Create new templates folder" : "Креирај нови фолдер шаблона",
    "List of favorites files and folders." : "Листа омиљених фајлова и директоријума.",
    "Toggle %1$s sublist" : "Укљ./искљ. %1$s подлисте",
    "Text file" : "Tекстуални фајл",
    "New text file.txt" : "Нов текстуални фајл.txt",
    "Direct link was copied (only works for people who have access to this file/folder)" : "Копиран је директан линк (функционише само за особе који имају приступ овом фајлу/фолдеру)",
    "Copy direct link (only works for people who have access to this file/folder)" : "Копирај директни линк (ради само за особе које имају приступ овом фајлу/фолдеру)",
    "Favored" : "Наклоњен",
    "Favor" : "Наклоност",
    "Not favored" : "Ненаклоњен"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
